@@ -17,13 +17,13 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with with program; see the file COPYING. If not, write to the
-# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-# MA 02111-1307 USA
+# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+# MA 02110-1301 USA
 
-id = "3237f92275c0470bceb2b2450933779d62782cb3"
-date = "2020-06-24 19:55:43 +0000"
+id = "a91833b2ce19e031bf09b2e62e1b8cff08779d15"
+date = "2024-08-20 15:10:39 +0000"
 branch = "None"
-tag = "lalmetaio-v1.6.1"
+tag = "lalmetaio-v4.0.5"
 if tag == "None":
     tag = None
 author = "Adam Mercer <adam.mercer@ligo.org>"
@@ -32,8 +32,8 @@ committer = "Adam Mercer <adam.mercer@ligo.org>"
 status = "CLEAN: All modifications committed"
 version = id
 verbose_msg = """Branch: None
-Tag: lalmetaio-v1.6.1
-Id: 3237f92275c0470bceb2b2450933779d62782cb3
+Tag: lalmetaio-v4.0.5
+Id: a91833b2ce19e031bf09b2e62e1b8cff08779d15
 
 Builder: Adam Mercer <adam.mercer@ligo.org>
 Repository status: CLEAN: All modifications committed"""
@@ -54,9 +54,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError(onmismatch + " is an unrecognized value of onmismatch")
-    if foreign_id == "3237f92275c0470bceb2b2450933779d62782cb3":
+    if foreign_id == "a91833b2ce19e031bf09b2e62e1b8cff08779d15":
         return
-    msg = "Program id (3237f92275c0470bceb2b2450933779d62782cb3) does not match given id (%s)." % foreign_id
+    msg = "Program id (a91833b2ce19e031bf09b2e62e1b8cff08779d15) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError(msg)
 
